@@ -5,11 +5,9 @@ Author: E Dennison
 
 from collections import namedtuple
 import os
-import redis
 
 ENV_GITHUBCLIENTID = "githubclientid"
 ENV_GITHUBSECRET = "githubsecret"
-ENV_DEVTOKEN = "githubtoken"
 ENV_GOOGLECLIENTID = "googleclientid"
 ENV_GOOGLEAPIKEY = "googleapikey"
 ENV_GOOGLEAPPID = "googleappid"
@@ -18,8 +16,6 @@ ENV_SITETITLE = "sitetitle"
 ENV_SITECONTACT = "sitecontact"
 ENV_SITEURL = "siteurl"
 ENV_DEBUG = "debug"
-ENV_REDIS_HOST = "redishost"
-ENV_REDIS_PORT = "redisport"
 
 SESSION_GITHUBSTATE = "githubstate"
 SESSION_ACCESSTOKEN = "accesstoken"
@@ -30,9 +26,7 @@ SESSION_GITHUBREPO = "githubrepo"
 SESSION_GITHUBPATH = "githubpath"
 SESSION_METADATA = "metadata"
 
-CACHE_VERSION = "2"
 Context = namedtuple("Context", ["user", "repo", "path"])
-Cachedata = namedtuple("Cachedata", ["contents", "sha", "etag"])
 
 RUN_EDIT = "run_edit"
 AUTH_REQUEST = "auth_request"
@@ -47,9 +41,3 @@ INIT_CONTENT = 'print("Hello, world.")'
 
 BRYTHON_FOLDER = "static/brython"
 BRYTHON_JS = "brython.js"
-
-REDIS_HOST = os.environ.get(ENV_REDIS_HOST, "0.0.0.0")
-REDIS_PORT = os.environ.get(ENV_REDIS_PORT, "6379")
-
-CACHE_CLIENT = redis.Redis(host=REDIS_HOST, port=REDIS_PORT)
-CACHE_TIMEOUT_S = 60 * 60 * 24
